clover_wallpaper
==================

cloverwallpaper makes it simple to fetch all images on a 4chan board for a specified resolution, making it ideal for finding wallpapers.

Installation
---------------

### Dependencies

cloverwallpaper requires:
 
 - Python (>= 3.6)
 - twdm
 - requests

### User installation

```
pip install cloverwallpaper
```

Usage
---------

```
usage: __main__.py [-h] --board BOARD --height HEIGHT --width WIDTH
-h, --help       show this help message and exit
--board BOARD    target board to scrape images from
--height HEIGHT  height of the images you wish to download
--width WIDTH    width of the images you wish to download
```
